View source: R/permutation_test.R
| one_sample | R Documentation |
This function runs a permutation test for the one-sample problem by calling the permutation_test function using the one-sample mean test statistic.
one_sample(x, shift = 0, alternative = "greater", reps = 10^4, seed = NULL)
x |
array of data |
shift |
Value of shift to apply in one-sample problem |
alternative |
String, two-sided or one-sided (greater or less) p-value |
reps |
Number of iterations to use when calculating permutation p-value |
seed |
An integer seed value |
The permutation test p-value
one_sample(x = c(-1, 1, 2), seed = 42)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.