This function takes a data frame, and group and outcome column names as input and returns the one-way anova test statistic
one_way_anova_stat(df, group_col, outcome_col)The one-way anova test statistic: \(\sum_{g=1}^G n_g(\overline{X_g} - \overline{X})^2\) where \(g\) indexes the groups
A data frame
The name of the column in df that corresponds to the group label
The name of the column in df that corresponds to the outcome variable