powered by
This function takes a data frame and group and outcome column name as input and returns the dataframe with the group column replaced with randomly assigned signs
permute_sign(df, group_col, strata_col = NULL, seed = NULL)
The inputted data frame with the group column replaced with randomly assigned signs
A data frame
The name of the column in df that corresponds to the group label
The name of the column in df that corresponds to the strata, should be NULL for this function
An integer seed value
data <- data.frame(group_label = rep(1, 6), outcome = 1:6) permute_group(df = data, group_col = "group_label", strata_col = NULL, seed = 42)
Run the code above in your browser using DataLab