ttest_stat: Calculate t-test statistic
Description
This function takes a data frame, and group and outcome column names as input
and returns the t test statistic
Usage
ttest_stat(df, group_col, outcome_col)
Value
The t test statistic
Arguments
- df
A data frame
- group_col
The name of the column in df that corresponds to the group label
- outcome_col
The name of the column in df that corresponds to the outcome variable